Learn R Programming

docxtractr (version 0.1.0.9000)

docx_describe_tbls: Returns a description of all the tables in the Word document

Description

This function will attempt to discern the structure of each of the tables in docx and print this information

Usage

docx_describe_tbls(docx)

Arguments

docx
docx object read with read_docx

Examples

Run this code
complx <- read_docx(system.file("examples/complex.docx", package="docxtractr"))
docx_tbl_count(complx)
docx_describe_tbls(complx)

Run the code above in your browser using DataLab