docx_extract_tbl: Extract a table from a Word document
Description
Given a document read with read_docx and a table to extract (optionally
indicating whether there was a header or not and if cell whitepace trimming is
desired) extract the contents of the table to a data.frame.
Usage
docx_extract_tbl(docx, tbl_number = 1, header = TRUE, trim = TRUE)
Arguments
docx
docx object read with read_docx
tbl_number
which table to extract (defaults to 1)
header
assume first row of table is a header row? (default; TRUE)
trim
trim leading/trailing whitespace (if any) in cells? (default: TRUE)